==> qmapshack_1.15.0.orig.tar.gz: qmapshack-V_1.15.0/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Important Notice:**

**Do not delete any of the sections. Answer them. If you really**
**think they do not apply to you give a short statement. Bug**
**reports that are not properly filed might be closed without**
**further notice.**

**Choose a good title**

What is a good title?
The title will be listed in the changelog when the issue is fixed. Do
you think someone else would understand what's fixed or done from your
title? Does it really name the real topic of the issue?

[ ] Did you choose a good title?

**Describe the bug**

A clear and concise description of what the bug is.

**What have you done to circle down the problem?**

Did you compare to previous versions? What versions? Did you check
if others have the same problem?

**To Reproduce**

Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**

A clear and concise description of what you expected to happen.

**Screenshots**

If applicable, add screenshots to help explain your problem.

**Attachments**

Can you provide an example file to trigger the problem?

**Tracebacks**

If QMapshack crashes the fastest way to get help is a backtrace. We are
aware that it's not that easy to record one. However if you provide one
chances are good to have it solved very fast. If the problem can't be
reproduced on the developer's environment we will sooner or later request
a traceback.

For Linux see:
https://github.com/Maproom/qmapshack/wiki/TroubleShooting#create-a-backtrace-of-a-crash-on-linux

For Windows it would need a debug build and running QMapshack in Visual Studio.

**Desktop (please complete the following information):**

 - OS: [e.g. OS X, Debian, Suse, Windows]
 - QMapShack Version [e.g. 1.13.1]
 - Window Manager [e.g. KDE, GNOME]

**Additional context**

Add any other context about the problem here.

==> qmapshack_1.15.2.orig.tar.gz: qmapshack-V_1.15.2/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Important Notice:**

**Do not delete any of the sections. Read what is requested.**
**_Replace(!)_ the instructions by your _answer(!)_. Bug**
**reports that are not properly filed might be closed without**
**further notice.**

**Choose a good title**

What is a good title?
The title will be listed in the changelog when the issue is fixed. Do
you think someone else would understand what's fixed or done from your
title? Does it really name the real topic of the issue?

[ ] Did you choose a good title?

**Describe the bug**

A clear and concise description of what the bug is.

**What have you done to circle down the problem?**

Did you compare to previous versions? What versions? Did you check
if others have the same problem?

**To Reproduce**

Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**

A clear and concise description of what you expected to happen.

**Screenshots**

If applicable, add screenshots to help explain your problem.

**Attachments**

Can you provide an example file to trigger the problem?

**Tracebacks**

If QMapshack crashes the fastest way to get help is a backtrace. We are
aware that it's not that easy to record one. However if you provide one
chances are good to have it solved very fast. If the problem can't be
reproduced on the developer's environment we will sooner or later request
a traceback.

For Linux see:
https://github.com/Maproom/qmapshack/wiki/TroubleShooting#create-a-backtrace-of-a-crash-on-linux

For Windows it would need a debug build and running QMapshack in Visual Studio.

**Desktop (please complete the following information):**

 - OS: [e.g. OS X, Debian, Suse, Windows]
 - QMapShack Version [e.g. 1.13.1]
 - Window Manager [e.g. KDE, GNOME]

**Additional context**

Add any other context about the problem here.
